aboutsummaryrefslogtreecommitdiffstats
path: root/include/asm-sparc64/oplib.h
diff options
context:
space:
mode:
authorDavid S. Miller <davem@sunset.davemloft.net>2006-02-15 02:26:54 -0800
committerDavid S. Miller <davem@sunset.davemloft.net>2006-03-20 01:13:04 -0800
commit7890f794e0e6f7dce2a5f4a03ba64b0b3fe306bd (patch)
treea9cc7c67498616a47108c667a9c001f9fe468318 /include/asm-sparc64/oplib.h
parent[SPARC64]: Fix pci_intmap_match(). (diff)
downloadlinux-dev-7890f794e0e6f7dce2a5f4a03ba64b0b3fe306bd.tar.xz
linux-dev-7890f794e0e6f7dce2a5f4a03ba64b0b3fe306bd.zip
[SPARC64]: Add prom_{start,stop}cpu_cpuid().
Use prom_startcpu_cpuid() on SUN4V instead of prom_startcpu(). We should really test for "SUNW,start-cpu-by-cpuid" presence and use it if present even on SUN4U. Signed-off-by: David S. Miller <davem@davemloft.net>
Diffstat (limited to 'include/asm-sparc64/oplib.h')
-rw-r--r--include/asm-sparc64/oplib.h14
1 files changed, 11 insertions, 3 deletions
diff --git a/include/asm-sparc64/oplib.h b/include/asm-sparc64/oplib.h
index 0631d13475f2..84618f8a9e6e 100644
--- a/include/asm-sparc64/oplib.h
+++ b/include/asm-sparc64/oplib.h
@@ -188,10 +188,18 @@ extern enum prom_output_device prom_query_output_device(void);
/* Multiprocessor operations... */
#ifdef CONFIG_SMP
/* Start the CPU with the given device tree node, context table, and context
* at the passed program counter.
*/
-extern void prom_startcpu(int cpunode, unsigned long pc, unsigned long o0);
+extern void prom_startcpu(int cpunode, unsigned long pc, unsigned long arg);
+
+/* Start the CPU with the given cpu ID at the passed program
+ * counter with the given arg passed in via register %o0.
+ */
+extern void prom_startcpu_cpuid(int cpuid, unsigned long pc, unsigned long arg);
+
+/* Stop the CPU with the given cpu ID. */
+extern void prom_stopcpu_cpuid(int cpuid);
/* Stop the current CPU. */
extern void prom_stopself(void);
@@ -188,10 +188,18 @@ extern enum prom_output_device prom_query_output_device(void);
/* Multiprocessor operations... */
#ifdef CONFIG_SMP
-/* Start the CPU with the given device tree node, context table, and context
- * at the passed program counter.
+/* Start the CPU with the given device tree node at the passed program
+ * counter with the given arg passed in via register %o0.
*/